# PyWaterRocket
PyWaterRocket est un module Python simple d'utilisation et intuitif fait pour la simulation de tir de fusée à eau amateurs à base de bouteille d'eau ou de limonade. Ce module fait suite au projet de conception et d'instrumentation d'une fusée à eau dans le cadre du programme d'échange Erasmus + entre Polytech Paris-Saclay et l'Ecole Nationale Polytechnique. Ce projet a pour inspiration un travail fait précédemment sous forme d'un fichier Excel (le fichier simulateurV1.xls) fait par ... 
## Principales features
- Calcul des constantes physiques concernant les tirs de fusées à eau 
- Prend en considération les paramètres de formes de la bouteilles
- Calcul des variables suivantes durant le vol : 
    - Vitesse d'éjection de l'eau et de l'air de la bouteille
    - La poussée de la fusée
    - La résistance de l'air
    - La position x(t) et y(t)
    - La vitesse de la fusée
    - L'inclinaison de la fusée
    - L'accélération de la fusée
## Validation
TODO : EN COURS
## Documentation 
TODO : Mettre un notebook explicatif des fonctionnalités sur colab
## Getting Started
